@@ -306,7 +306,7 @@ do_test (GNOME_Speech_SynthesisDriver driver, CORBA_Environment *ev)
 		return -1;
 	}
 	GNOME_Speech_Speaker_stop (speaker, ev);
-	speaker_say_print (speaker, "\nPlease select a test.\n\n");
+	speaker_say_print (speaker, "\nPlease select a \"test\".\n\n");
 	speaker_say_print (speaker, "1. Parameter test.\n");
 	speaker_say_print (speaker, "2. Callback test.\n");
 	speaker_say_print (speaker, "3. Speech Interrupt test.\n");
